AdsenseWeb class

A web implementation of the AdsensePlatform of the Adsense plugin.

Inheritance
  • Object
  • PlatformInterface
  • AdsensePlatform
  • AdsenseWeb

Constructors

AdsenseWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

adView() Widget
override
initialize() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

addMasterScript() → void
registerPlatformView() → void
registerWith(Registrar registrar) → void